@@ -131,5 +131,7 @@ class HVAC(Consumer):
         test_state = deepcopy(self.state)
         self._check_constraints(test_state)
         return self._get_percent(
-            test_state.p_kw, self.get_pn_min_kw(), self.get_pn_max_kw()
+            test_state.p_kw,
+            self.get_pn_min_kw(),
+            self.get_pn_max_kw(),
         )
