@@ -1,5 +1,5 @@
 """
-This module contains a model of a chp system with a chp and a 
+This module contains a model of a chp system with a chp and a
 household. The household has a heat demand which allows the chp
 to run for at least 5000 hours in a year.
 
@@ -52,10 +52,11 @@ class CHPLPGSystem(Generator):
         self.heatdemand.step()
 
         # Second step the chp
-        self.chp.inputs.now = self.inputs.now
+        p_set_kw = self._check_setpoint()
+        self.chp.set_now_dt(self.inputs.now_dt)
         self.chp.inputs.e_th_demand_set_kwh = self.heatdemand.state.e_th_kwh
-        self.chp.inputs.step_size = self.inputs.step_size
-        self.chp.inputs.p_set_kw = self.inputs.p_set_kw
+        self.chp.set_step_size(self.inputs.step_size)
+        self.chp.set_p_kw(p_set_kw * self.config.gsign)
         self.chp.step()
 
         # Update the references
@@ -67,6 +68,16 @@ class CHPLPGSystem(Generator):
 
         self.inputs.reset()
 
+    def _check_setpoint(self):
+        setpoint = self.inputs.p_set_kw
+        if setpoint is not None:
+            return abs(setpoint)
+        hour = self.inputs.now_dt.hour
+        default = self.config.default_schedule[hour]
+        setpoint = self.config.p_max_kw * default / 100
+
+        return abs(setpoint)
+
     def get_state(self):
         """Get state"""
         state_dict = {
@@ -86,11 +97,11 @@ class CHPLPGSystem(Generator):
         self.state.storage_t_c = self.chp.state.storage_t_c
         self.state.lubricant_l = self.chp.state.lubricant_l
 
-    @property
-    def set_percent(self):
-        return self.chp.set_percent
+    # @property
+    # def set_percent(self):
+    #     return self.chp.set_percent
 
-    @set_percent.setter
-    def set_percent(self, value):
-        self.chp.set_percent = value
-        self.inputs.p_set_kw = self.chp.inputs.p_set_kw
+    # @set_percent.setter
+    # def set_percent(self, value):
+    #     self.chp.set_percent = value
+    #     self.inputs.p_set_kw = self.chp.inputs.p_set_kw
